%bcond_without doc
%bcond_without gtk

%ifarch %{ocaml_native_compiler}
%global native true
%else
%global native false
%endif

Name:           unison
Version:        2.53.4
Release:        1%{?dist}
Summary:        Unison File Synchronizer

%global         forgeurl https://github.com/bcpierce00/%{name}/
%global         tag v%{version}
%forgemeta

License:        GPL-3.0-or-later
URL:            %{forgeurl}
Source0:        %{forgesource}

BuildRequires:  ocaml
BuildRequires:  ocaml-findlib

%if %{with gtk}
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  ocaml-lablgtk3-devel
BuildRequires:  ocaml-cairo-devel
%endif
%if %{with doc}
BuildRequires:  hevea
BuildRequires:  lynx
BuildRequires:  texlive-latex
%endif

%description
Unison is a file-synchronization tool for POSIX-compliant systems (e.g. *BSD,
GNU/Linux, macOS) and Windows.  It allows two replicas of a collection of files
and directories to be stored on different hosts (or different disks on the same
host), modified separately, and then brought up to date by propagating the
changes in each replica to the other.

%if %{with gtk}
%package        gtk
Summary:        Unison File Synchronizer GTK interface
Requires:       hicolor-icon-theme
%description    gtk
%{summary}.
%endif

%if %{with doc}
%package        doc
Summary:        Unison File Synchronizer documentation
BuildArch:      noarch
%description    doc
%{summary}.
%endif

%prep
%forgeautosetup

%build
%make_build        \
  NATIVE=%{native} \
  tui              \
  fsmonitor        \
  manpage

%if %{with gtk}
%make_build        \
  NATIVE=%{native} \
  gui

cat > %{name}.desktop <<EOF
[Desktop Entry]
Type=Application
Exec=%{name}-gui
Name=Unison File Synchronizer
GenericName=File Synchronizer
Comment=Multi-master File synchronization tool
Terminal=false
Icon=%{name}
StartupNotify=true
Categories=Utility;
EOF
%endif

%if %{with doc}
%make_build        \
  NATIVE=%{native} \
  docs
%endif

%install
%make_install PREFIX=%{_prefix}

%if %{with gtk}
# Install the various icons according to the "Icon Theme Specification"
# https://specifications.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
for size in 16 24 32 48 256; do
  format="${size}x${size}"
  %{__install} -Dpm0644 icons/U.${format}x16m.png \
    %{buildroot}%{_datadir}/icons/hicolor/${format}/apps/%{name}.png
done
%{__install} -Dpm0644 icons/U.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{name}.desktop
%endif

%if %{with doc}
%{__install} -Dpm0644 -t %{buildroot}%{_docdir}/%{name} doc/%{name}-manual.{html,pdf,txt}
%endif

%files
%doc NEWS.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-fsmonitor
%{_mandir}/man1/%{name}.1*

%if %{with gtk}
%files          gtk
%license LICENSE
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%endif

%if %{with doc}
%files          doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/%{name}-manual.{html,pdf,txt}
%endif

%changelog
* Sat Apr 20 2024 Matthew Krupcale <mkrupcale@gmail.com> - 2.53.4-1
- Initial package
